# remirepo spec file for php-snappy
#
# Copyright (c) 2016-2020 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%global sub_prefix  %{scl_prefix}
%scl_package        php-snappy
%else
%global pkg_name    %{name}
%endif

# To build with PHP 5.x use --without apcu
%bcond_without apcu

%if 0%{?fedora} >= 32
%global with_libsnappy 1
%else
%global with_libsnappy 0
%endif

%global gh_commit   e42cc15bb38140eae95a295a105ddcbf391dcb7c
%global gh_short    %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner    kjdev
%global gh_project  php-ext-snappy
#global gh_date     20160608
%global pecl_name   snappy
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global ini_name    40-%{pecl_name}.ini

%if ! 0%{?dtsversion}
%if 0%{?rhel} == 6
%global dtsenable export PHP_AUTOCONF=autoconf268;export PHP_AUTOHEADER=autoheader268;source /opt/rh/devtoolset-7/enable
BuildRequires: devtoolset-7-toolchain
BuildRequires: autoconf268
%endif
%if 0%{?rhel} == 7
%global dtsenable source /opt/rh/devtoolset-7/enable
BuildRequires: devtoolset-7-toolchain
%endif
%endif

Summary:       Snappy Extension for PHP
Name:          %{?sub_prefix}php-snappy
Version:       0.2.0
%if 0%{?gh_date:1}
Release:       1%{gh_date}git%{gh_short}%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
%else
Release:       1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
%endif
%if %{?with_libsnappy}
License:       PHP
%else
License:       PHP and BSD
%endif
URL:           https://github.com/%{gh_owner}/%{gh_project}
Source0:       %{pkg_name}-%{version}-%{gh_short}.tgz
# retrieve a recursive git snapshot with submodule
Source1:       makesrc.sh

%if %{with apcu}
BuildRequires: %{?scl_prefix}php-devel > 7
BuildRequires: %{?scl_prefix}php-pecl-apcu-devel
%else
BuildRequires: %{?scl_prefix}php-devel
%endif
%if %{?with_libsnappy}
BuildRequires: snappy-devel
%else
Provides:      bundled(snappy) = 1.1.8
%endif

Requires:      %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:      %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

%if "%{?packager}" == "Remi Collet" && 0%{!?scl:1} && 0%{?rhel}
%if "%{php_version}" > "7.3"
Obsoletes:     php73-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "7.4"
Obsoletes:     php74-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "8.0"
Obsoletes:     php80-%{pecl_name} <= %{version}
%endif
%endif

%if 0%{?fedora} < 20 && 0%{?rhel} < 7
# Filter shared private
%{?filter_provides_in: %filter_provides_in %{_libdir}/.*\.so$}
%{?filter_setup}
%endif


%description
This extension allows Snappy, a compression/decompression library.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -qc
mv %{gh_project}-%{gh_commit} NTS

cd NTS
%if %{?with_libsnappy}
# Use the system library
rm -r snappy
%else
# Refresh snappy License file
cp -r snappy/COPYING COPYING.snappy
%endif

# Sanity check, really often broken
extver=$(sed -n '/#define SNAPPY_EXT_VERSION/{s/.* "//;s/".*$//;p}' php_snappy.h)
if test "x${extver}" != "x%{version}%{?gh_date:-dev}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?gh_date:-dev}.
   exit 1
fi
cd ..

%if %{with_zts}
# duplicate for ZTS build
cp -pr NTS ZTS
%endif

# Drop in the bit of configuration
cat << 'EOF' | tee %{ini_name}
; Enable '%{summary}' extension module
extension = %{pecl_name}.so
EOF


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
    --with-php-config=%{_bindir}/php-config \
%if %{?with_libsnappy}
    --with-snappy-includedir=/usr \
%endif
    --with-libdir=%{_lib} \
    --enable-snappy
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --with-php-config=%{_bindir}/zts-php-config \
%if %{?with_libsnappy}
    --with-snappy-includedir=/usr \
%endif
    --with-libdir=%{_lib} \
    --enable-snappy
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

# Install the NTS stuff
make -C NTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

%if %{with_zts}
# Install the ZTS stuff
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif



%check
cd NTS
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if "%{php_version}" > "7.0"
: Check that apcu is aware of snappy serializer
%{__php} --no-php-ini \
    --define extension=apcu.so \
    --define apc.enabled=1 \
    --define apc.enable_cli=1 \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --ri apcu | grep '%{pecl_name}'
%endif

: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php --show-diff || : ignore

%if %{with_zts}
cd ../ZTS
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

: Upstream test suite  for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php --show-diff
%endif


%files
%{!?_licensedir:%global license %%doc}
%license NTS/LICENSE
%if ! %{?with_libsnappy}
%license NTS/COPYING.snappy
%endif
%doc NTS/CREDITS
%doc NTS/README.md

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Mon Sep 28 2020 Remi Collet <remi@remirepo.net> - 0.2.0-1
- update to 0.2.0
- enable apcu serializer with PHP 7+

* Thu Sep 10 2020 Remi Collet <remi@remirepo.net> - 0.1.12-1
- update to 0.1.12

* Fri Jun  5 2020 Remi Collet <remi@remirepo.net> - 0.1.11-1
- update to 0.1.11

* Fri May 29 2020 Remi Collet <remi@remirepo.net> - 0.1.10-1
- update to 0.1.10 with libsnappy 1.1.8

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.1.9-4
- rebuild for 7.4.0RC1

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 0.1.9-3
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 0.1.9-2
- rebuild for 7.3.0alpha4 new ABI

* Fri Sep  8 2017 Remi Collet <remi@remirepo.net> - 0.1.9-1
- update to 0.1.9 (no change)

* Mon Aug 28 2017 Remi Collet <remi@remirepo.net> - 0.1.8-1
- update to 0.1.8 with bundled libsnappy 1.1.7

* Wed Jul 19 2017 Remi Collet <remi@remirepo.net> - 0.1.7-1
- update to 0.1.7 (no change)

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 0.1.6-2
- rebuild for PHP 7.2.0beta1 new API

* Sun Feb  5 2017 Remi Collet <remi@fedoraproject.org> - 0.1.6-1
- update to 0.1.6 (no change)

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 0.1.5-3
- rebuild with PHP 7.1.0 GA

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 0.1.5-2
- rebuild for PHP 7.1 new API version

* Thu Sep  8 2016 Remi Collet <remi@fedoraproject.org> - 0.1.5-1
- update to 0.1.5 (no change)

* Wed Sep  7 2016 Remi Collet <remi@fedoraproject.org> - 0.1.4-1
- update to 0.1.4 (no change)
- drop patch merged upstream

* Tue Sep  6 2016 Remi Collet <remi@fedoraproject.org> - 0.1.3-1
- new package, version 0.1.3
- add patch to build with system libsnappy
  open https://github.com/kjdev/php-ext-snappy/pull/4

